<?php
/**
 * Plugin Qcm (addon for plugin Adm_redacteurs)
 * Version  : 1.5 (2021/01/03)
 * Compatibility : Guppy v5.x et v6.00.00 et Adm_redacteurs v6.14+
 * Author   : jérôme CROUX (jchouix)
 * Web site : http://lebrikabrak.info/
 * E-mail   : lebrikabrak@free.fr
 * Licence  : GNU Lesser General Public License
 */

defined('ADMR_DIRNAME') OR exit('No direct script access allowed');

require ADMR_CORE_PATH.'/admin_controller.php';

class Admin_check_qcm_data_integrity_controller extends Admin_controller
{
    /*
    |--------------------------------------------------------------------------
    | Properties
    |--------------------------------------------------------------------------
    */
    protected $_lang = array();         // Données de langue
    protected $_config = array();       // Données de configuration
//    protected $_params = array();       // Données récupérés par post ou get
//    protected $_sort_options = array();	// Options de tri    
  
    /*
    |--------------------------------------------------------------------------
    | Constructor
    |--------------------------------------------------------------------------
    */    
    function __construct()
    {
        parent :: __construct();       
        
        $this -> load_helper('url_helper');
        $this -> load_helper('var_helper');
        $this -> load_helper('security_helper');
        $this -> load_helper('file_helper');
        
        $this -> load_addon_helper('qcm', 'plugin_menu_for_qcm_helper');
        $this -> load_addon_helper('qcm', 'qcm_infos_helper');
        
        $this -> load_addon_model('qcm', 'qcm_ids_model');
        $this -> load_addon_model('qcm', 'qcm_params_model');
        $this -> load_addon_model('qcm', 'qcm_counters_model');
        $this -> load_addon_model('qcm', 'qcm_menuitems_model');
        
        $this -> load_model('guppy_docid_model'); // Model des documents de guppy
        $this -> load_model('guppy_doc_model'); // Model des documents de guppy
        $this -> load_model('menuitems_model'); // Model des items de menus
        
        $this -> load_addon_lang('qcm');
        $this -> load_addon_config('qcm');        

        $this -> _lang = $this -> get_lang();
        $this -> _config = $this -> get_config();
    }

    /*
    |--------------------------------------------------------------------------
    | Methods
    |--------------------------------------------------------------------------
    */

    public function index()
    {        
        $this -> check_integrity();
    }

	// --------------------------------------------------------------------

    public function check_integrity()
    {
        set_time_limit(0);
        
        /**
         * Maintenance des données
         */
        $action = Var_helper :: import('action', 'post', 0, array(), array(array('Var_helper', 'is_alpha_num_dash')));
        $ids = Var_helper :: import('ids', 'post', array(), array(), array(array('Var_helper', 'is_digit')));
        $choice = Var_helper :: import('choice', 'post', 0, array(), array(array('Var_helper', 'is_digit')));
        
        $token_name = 'ADMR_check_data_integrity';
        $token_time_expire = $this -> _config['token_time_expire'];
        $referer = ADMR_SITE_URL.'admin/'.ADMR_BASE_HREF_PLUGIN.'&ctrl='.ADMR_CONTROLLER;
        $message = '';
        
        if (!empty($_POST) && Security_helper :: check_token($token_time_expire, $referer, $token_name) ) {            
 
            if ($action == 'qcm') {  // Maintenance des données des documents           
                if ($choice == 1) {
                    $this -> _check_qcm_integrity();
                } elseif ($choice == 2 && !empty($ids)) {
                    $this -> _check_qcm_integrity($ids);    
                }
                               
                $message = ucfirst(sprintf($this -> _lang['the(m)_%s_succeeded'], $this -> _lang['control_of_integrity_of_qcm_data']));
            }
            else if ($action == 'menuitem') { // Maintenance des données des items de menu associés aux documents
                if ($choice == 1) {
                    $this -> _check_qcm_menuitems_integrity();
                } elseif ($choice == 2 && !empty($ids)) {
                    $this -> _check_qcm_menuitems_integrity($ids);    
                }
                $message = ucfirst(sprintf($this -> _lang['the(m)_%s_succeeded'], $this -> _lang['control_of_integrity_of_qcm_menuitems']));
            }
        }     
        //

        $data = array(
            'message' => $message,
            'lang' => $this -> _lang,
            'form_uri' => ADMR_BASE_HREF_PLUGIN.'&amp;ctrl='.ADMR_CONTROLLER,
            'token' => Security_helper :: create_token($token_name),
            'qcms' => $this -> _get_qcms(),
            'menuitems' => $this -> _get_qcm_menuitems(),
            'action' => $action,
            'ids' => $ids,
            'choice' => $choice
        );

        parent :: render_page(str_replace(ADMR_PUBLIC_ROOT_PATH, '..', QCM_VIEWS_PATH).'/check_qcm_data_integrity', $data);
    }
        
	// --------------------------------------------------------------------

	/**
	 * Contrôle l'intégrité les données du fichier qcm_ids.dtb
     * 
     * @access private
     * @param array Tableau contenant les identifiants des documents à contrôler (tous par défaut)
	 * @return void
	 */
    private function _check_qcm_integrity($qcm_ids = array())
    {
        $this -> _check_qcm_ids_integrity($qcm_ids);
        $this -> _check_qcm_params_integrity();
        $this -> _check_qcm_counters_integrity();
        
        return TRUE;
    }
        
	// --------------------------------------------------------------------

	/**
	 * Contrôle l'intégrité les données du fichier qcm_ids.dtb
     * 
     * @access private
     * @param array Tableau contenant les identifiants des documents à contrôler (tous par défaut)
	 * @return void
	 */
    private function _check_qcm_ids_integrity($qcm_ids = array())
    {
        settype($qcm_ids, 'array');
        
        if (empty($qcm_ids)) {
            $qcm_ids = array_keys($this -> qcm_ids_model -> get());    
        }

        $qcm_to_delete = array();
        
        foreach($qcm_ids as $qcm_id) {
            if ($this -> qcm_params_model -> file_exists($qcm_id) === FALSE) {
                $qcm_to_delete[] = $qcm_id;
            }
        }
        
        $this -> qcm_ids_model -> delete_by_id($qcm_to_delete);    
        
        return TRUE;
    }
        
	// --------------------------------------------------------------------

	/**
	 * Contrôle l'intégrité des fichiers qcm_params_XX.inc
     * 
     * @access private
	 * @return void
	 */
    private function _check_qcm_params_integrity()
    {
        $qcm_missing = array();
        $qcm_params_ids = $this -> qcm_params_model -> get_files_ids();
        
        foreach($qcm_params_ids as $qcm_id) {
            $qcm = $this -> qcm_ids_model -> get_by_id($qcm_id);
            
            if (empty($qcm)) {
                $qcm_missing[] = array_merge($this -> qcm_params_model -> read($qcm_id), array('status' => 'i', 'mode' => 2));                        
            }
        }
        
        $this -> qcm_ids_model -> update_many($qcm_missing);
        
        return TRUE;            
    }
        
	// --------------------------------------------------------------------

	/**
	 * Contrôle l'intégrité des compteurs des fichiers qcm_counter_XX.inc
     * 
     * @access private
	 * @return void
	 */
    private function _check_qcm_counters_integrity()
    {
        $qcm_counters_to_delete = array();
        $qcm_counters_ids = $this -> qcm_counters_model -> get_files_ids();
        
        foreach($qcm_counters_ids as $qcm_id) {
            $qcm = $this -> qcm_ids_model -> get_by_id($qcm_id);
            
            if (empty($qcm)) {
                $qcm_counters_to_delete[] = $qcm_id;                        
            }
        }

        $this -> qcm_counters_model -> delete_by_id($qcm_counters_to_delete);
        
        return TRUE;            
    }
         
	// --------------------------------------------------------------------

	/**
	 * Contrôle l'intégrité les données des items de menu associés aux fichiers html
     * 
     * @access private
     * @param array Tableau contenant les identifiants des documents à contrôler (tous par défaut)
	 * @return void
	 */
    private function _check_qcm_menuitems_integrity($qcm_ids = array())
    {
        settype($qcm_ids, 'array');        
        
        $qcm_menuitems = $this -> qcm_menuitems_model -> get(array('id_qcm' => $qcm_ids));

        foreach($qcm_menuitems as $menuitem) {
            $menuitem += $this -> menuitems_model -> read($menuitem['id_menuitem']); 
            
            $qcm_id = $this -> menuitems_model -> extract_doc_id_from_item_url($menuitem['url1']);
            $qcm = $this -> qcm_ids_model -> get(array('id' => $qcm_id));
                  
            if (strpos($menuitem['url1'], QCM_PUBLIC_FILE_PATH) !== 0 || empty($qcm)) {                
                $this -> qcm_menuitems_model -> delete_by_menuitem_id($menuitem['id_menuitem']);  
            }
        }
        
        return TRUE;
    }
        
	// --------------------------------------------------------------------

	/**
	 * Contrôle l'intégrité des données des questions des qcm (fichiers qcm_questions_XX.inc)
     * 
     * @access private
     * @param array Tableau contenant les identifiants des qcm à contrôler (tous par défaut)
	 * @return void
	 */
    private function _check_qcm_questions_integrity($qcm_ids = array())
    {
        // TODO
 /*       $qcm_counters_to_delete = array();
        $qcm_counters_ids = $this -> qcm_counters_model -> get_files_ids();
        
        foreach($qcm_counters_ids as $qcm_id) {
            $qcm = $this -> qcm_ids_model -> get_by_id($qcm_id);
            
            if (empty($qcm)) {
                $qcm_counters_to_delete[] = $qcm_id;                        
            }
        }

        $this -> qcm_counters_model -> delete_by_id($qcm_counters_to_delete);
 */       
        return TRUE;            
    }

	// --------------------------------------------------------------------

	/**
	 * récupère tous les documents qcm enregistrés 
     * 
     * @access private
	 * @return array
	 */	
    private function _get_qcms()
    {
        return $this -> qcm_ids_model -> get();
    }

	// --------------------------------------------------------------------

	/**
	 * récupère tous les items de menu enregistrés associés aux documents qcm
     * 
     * @access private
	 * @return array
	 */	
    private function _get_qcm_menuitems()
    {
        $qcms = array();
        $qcm_menuitems = $this -> qcm_menuitems_model -> get();
        
        foreach($qcm_menuitems as $item) {
            $qcms[$item['id_qcm']] = array_merge($item, $this -> qcm_ids_model -> get_by_id($item['id_qcm']));   
        }
        
        return $qcms;
    }

	// --------------------------------------------------------------------

	/**
	 * définit les variables utilisées dans la page 
     * 
     * @access protected
	 * @return void
	 */	
/*    protected function set_params()
    {
        $this -> _params = parent :: set_params();
    }
*/    
	// --------------------------------------------------------------------

    /*
     * Définit et renvoie le titre de la page 
     *
     * @param array Données à faire passer à la vue
     * @return void
     */        
    public function set_title_page()
    {
        return ucfirst($this -> _lang['check_plugin_data_integrity']);
    }
    
	// --------------------------------------------------------------------

	/**
	 * définit et renvoie la description de la page ainsi que les recommendations
     * 
	 * @return string titre de la page
	 * @access public
	 */	
    protected function _set_infos_page_content()
    {		
        return $this -> _lang['infos_page_check_plugin_data_integrity'];
    }
    
	// --------------------------------------------------------------------

	/**
	 * définit et renvoie des ajouts (js, css, code php) dans la partie <head> de la page 
     * 
	 * @return string titre de la page
	 * @access public
	 */	
    public function set_header_addons()
    {
        $parent_addons = parent :: set_header_addons();
        
        $js = '';
        $js .= '<script type="text/javascript" src="'.ADMR_JS_PATH.'/waiting_process.js"></script>'."\n";
      
        $css = '';
        $css .= '<link rel="stylesheet" type="text/css" href="'.ADMR_CSS_PATH.'/form_validator.css" />'."\n";
        $css .= '<link rel="stylesheet" type="text/css" href="'.ADMR_CSS_PATH.'/waiting_process.css" />'."\n";
        $css .= '<link rel="stylesheet" type="text/css" href="'.ADMR_CSS_PATH.'/check_plugin_data_integrity.css" />'."\n";
 
        return $parent_addons.$js.$css;
    }

	// --------------------------------------------------------------------

    /**
     * Définit le contenu du menu du plugin qui est affiché en haut de la page
     *
     * @return array
     */
    protected function _set_menu_plugin_items()
    {
        return Plugin_menu_for_qcm_helper :: set_admin_items('qcm', $this -> _lang, $this -> _config, $this -> _admin_rights);
    }

	// --------------------------------------------------------------------

    /**
     * Définit le contenu des informations du plugin qui sont affichées en bas de la page
     *
     * @return array Tableau contenant les informations du plugin sous la forme array('version' => , 'licence' => )
     */
    protected function _set_infos_plugin()
    {
        return Qcm_infos_helper :: set_plugin_infos($this -> _lang);
    }

	// --------------------------------------------------------------------

} //End of Class