<?php
/**
 * Plugin Qcm (addon for plugin Adm_redacteurs)
 * Version  : 1.5 (2021/01/03)
 * Compatibility : Guppy v5.x et v6.00.00 et Adm_redacteurs v6.14+
 * Author   : jérôme CROUX (jchouix)
 * Web site : http://lebrikabrak.info/
 * E-mail   : lebrikabrak@free.fr
 * Licence  : GNU Lesser General Public License
 */

defined('ADMR_DIRNAME') OR exit('No direct script access allowed');

require_once ADMR_HELPERS_PATH.'/manage_records_helper.php';

class Manage_qcm_questions_helper extends Manage_records_helper
{
    /*
    |--------------------------------------------------------------------------
    | Properties
    |--------------------------------------------------------------------------
    */
    protected $CI; // object global
    protected $_lang = array();          // Données de langue
    protected $_config = array();        // Données de configuration
    protected $_params = array();        // Données récupérés par post ou get
    protected $_sort_options = array();	 // Options de tri

    protected $_doc_infos = array('name' => 'qcm_questions', 'type' => 'qcm'); // Tableau contenant les informations du document (nom, type)
    protected $_writer_rights = array(); // Droits du rédacteur
    //
    
    /*
    |--------------------------------------------------------------------------
    | Constructor
    |--------------------------------------------------------------------------
    */    
    public function __construct($writer_rights)
    {
        $this -> CI =& Controller :: get_instance();

        $this -> CI -> load_addon_lang('qcm');
        $this -> CI -> load_addon_config('qcm');        

        $this -> _lang = $this -> CI -> get_lang();
        $this -> _config = $this -> CI -> get_config();
        
        $this -> CI -> set_config_item('sort_option_by_default', $this -> _config['qcm_questions']['sort_option_by_default']); // Tri des enregistrements par défaut

        parent :: __construct();

        $this -> _writer_rights = $this -> _set_writer_rights($writer_rights);

        $this -> CI -> load_addon_helper('qcm', 'plugin_menu_for_qcm_helper');
        $this -> CI -> load_addon_helper('qcm', 'qcm_infos_helper');
                
        $this -> CI -> load_addon_model('qcm', 'qcm_ids_model');
        $this -> CI -> load_addon_model('qcm', 'qcm_questions_model');

//        $this -> CI -> load_addon_model('qcm', 'writer_qcm_model', array('id' => $this -> _writer_rights['id']));
        
        $this -> _qcm_id = $this -> _params['qcm_id'];

        /**
         * Controle de sécurité
         */
        if (! ADMR_IS_ADMIN && (! $this -> _is_qcm_allowed($this -> _qcm_id) || ! $this -> _is_doc_allowed())) {
            Url_helper :: redirect('display_error&type=disallowed');
        }
        //
        
        $this -> CI -> load_addon_model('qcm', 'qcm_questions_ids_model', array('qcm_id' => $this -> _qcm_id));
    }

    /*
    |--------------------------------------------------------------------------
    | Methods
    |--------------------------------------------------------------------------
    */

	/**
	 * définit les options de tri des données
     * 
     * @access protected
     * @param mixed Options de tri
	 * @return void
	 */	
    protected function _set_writer_rights($writer_rights)
    {
        settype($writer_rights, 'array');
        
        return $this -> _writer_rights = $writer_rights;	// Droits du rédacteur         
    }

	// --------------------------------------------------------------------

	/**
	 * définit les options de tri des données
     * 
     * @access protected
     * @param mixed Options de tri
	 * @return void
	 */	
    protected function _set_sort_options()
    {
        return $this -> _sort_options = array('id_asc', 'id_desc', 'order_asc', 'order_desc', 'ch_asc', 'ch_desc', 'up_asc', 'up_desc', 'status_asc', 'status_desc');	// Options de tri         
    }

	// --------------------------------------------------------------------

	/**
	 * définit les variables utilisées dans la page 
     * 
     * @access protected
	 * @return void
	 */	
    protected function _set_params()
    {
        $this -> _params = array_merge(
            parent :: _set_params(),
            array(
                'docid'  => trim(Var_helper :: import('docid', '', NULL, array('trim'), array(array('Var_helper', 'is_valid_ids'))), '-'),
                'writerid'  => trim(Var_helper :: import('writerid', '', NULL, array('trim'), array(array('Var_helper', 'is_valid_ids'))), '-'),
                'qcm_id' => Var_helper :: import('qcm_id', '', 0, array('trim'), array(array('Var_helper', 'is_digit'))),
            )
        );
       
        return $this -> _params;
    }

	// --------------------------------------------------------------------

	/**
	 * gére les enregistrements
     * 
     * @access public
	 * @return string code html
	 */	
    public function manage()
    {        
        parent :: manage();
    }

	// --------------------------------------------------------------------

	/**
	 * recherche des enregistrements et redirige vers la page qui va afficher les résultats de la recherche
     * 
     * @access public
	 * @return void
	 */
    public function search()
    {
        $uri = 'addons/qcm/manage_qcm_questions';
                
        if (!empty($this -> _params['qcm_id'])) {
            $uri .= '&qcm_id='.$this -> _params['qcm_id'];
        }
        
        Url_helper :: redirect($uri);       
    }

	// --------------------------------------------------------------------

    /**
     * Définit et renvoie le titre de la page 
     *
     * @access public
     * @return string titre de la page
     */        
    public function set_title_page()
    {
        return ucfirst($this -> _lang['manage_qcm_questions']);
    }
 
	// --------------------------------------------------------------------

	/**
	 * définit et renvoie les ajouts (js et css) dans l'entête de la page
     * 
     * @access public
	 * @return string Chaine html contenant les ajouts js et css
	 */	
    public function set_header_addons()
    {
        $parent_addons = parent :: set_header_addons(); 

        $js = '';
        $js .= '<script type="text/javascript" src="'.QCM_JS_PATH.'/qcm.js"></script>'."\n";
//        $js .= '<script type="text/javascript" src="'.QCM_JS_PATH.'/drag-and-drop.js"></script>'."\n";
        $js .= '<script type="text/javascript" src="'.ADMR_JS_PATH.'/table_dnd/jquery.tablednd.min.js"></script>'."\n";

        $css = '';
        $css .= '<link rel="stylesheet" type="text/css" href="'.QCM_CSS_PATH.'/qcm.css" />'."\n";
        $css .= '<link rel="stylesheet" type="text/css" href="'.ADMR_CSS_PATH.'/table_dnd/tablednd.css" />'."\n";

        return $css.$js.$parent_addons;        
    }
   
	// --------------------------------------------------------------------

	/**
	 * définit et renvoie la description de la page ainsi que les recommendations
     * 
     * @access public
     * @return string description de la page
	 */	
    public function set_infos_page_content()
    {		
        return $this -> _lang['infos_page_manage_qcm_questions'];
    }
    
	// --------------------------------------------------------------------

    /**
     * Définit le contenu du menu qui est affiché dans le bandeau en haut de la page
     * 
     * @access public
     * @return string menu de la page
	 */	
    public function set_menu_plugin_items()
    {        
        if (ADMR_IS_ADMIN) {
            return Plugin_menu_for_qcm_helper :: set_admin_items('qcm', $this -> _lang, $this -> _config, $this -> _writer_rights, $options = array('qcm_id' => $this -> _qcm_id));
        } else {
            return Plugin_menu_for_qcm_helper :: set_public_items('qcm', $this -> _lang, $this -> _config, $this -> _writer_rights, $options = array('qcm_id' => $this -> _qcm_id));
        }
    }

	// --------------------------------------------------------------------

    /**
     * Définit le contenu des informations du plugin qui sont affichées en bas de la page
     *
     * @return array Tableau contenant les informations du plugin sous la forme array('version' => , 'licence' => )
     */
    public function set_infos_plugin()
    {
        return Qcm_infos_helper :: set_plugin_infos($this -> _lang);
    }

	// --------------------------------------------------------------------

	/**
	 * synchronize les données des documents enregistrées pour le rédacteur avec ceux enregistrés dans le plugin qcm
     * 
     * @access protected
     * @param mixed Options de tri
	 * @return void
	 */	
    public function synchronize()
    {
//        $this -> CI -> writer_qcm_model -> synchronize($this -> CI -> qcm_questions_ids_model); // Synchronisation des enregistrements du rédacteur avec ceux de guppy
                		
		Url_helper :: redirect('addons/qcm/manage_qcm');
    }

	// --------------------------------------------------------------------

	/**
	 * retourne les enregistrements
     * 
     * @access protected
	 * @return array
	 */
    protected function _get_records()
    {
        $records = array();
        $qcm_id = $this -> _params['qcm_id'];
        $doc_ids = empty($this -> _params['docid']) ? array() : explode('-', $this -> _params['docid']);        
        $writer_id = empty($this -> _params['writerid']) ? array() : explode('-', $this -> _params['writerid']);
        $writer_id = ADMR_IS_ADMIN ?  $writer_id : $this -> _writer_rights['id'];
      
        if (!empty($qcm_id)) {
            $records = $this -> CI -> qcm_questions_ids_model -> get(array('qcm_id' => $qcm_id, 'author_id' => $writer_id, 'id' => $doc_ids, 'status' => array('a', 'i')), $this -> _params['sort']);
        }
/*
        if (ADMR_IS_ADMIN) {
            $records = $this -> CI -> qcm_questions_ids_model -> get(array('id' => $doc_ids, 'status' => array('a', 'i')), $this -> _params['sort']);    
        } else {
//            $records = $this -> CI -> writer_qcm_model -> get(array('id' => $doc_ids, 'status' => array('a', 'i')), $this -> _params['sort']);
        }*/
        
        return $records;
    }

	// --------------------------------------------------------------------

	/**
	 * retourne les enregistrements
     * 
     * @access protected
	 * @return array
	 */
/*    protected function _filter_records($records)
    {
        return $records;       
    }
*/    
	// --------------------------------------------------------------------

	/**
	 * Met à jour des données des enregistrements postés
     * 
     * @access public
	 * @return boolean
	 */	
/*    protected function _update_records()
    {
        return parent :: _update_records();
    }
*/
	// --------------------------------------------------------------------

	/**
	 * définit les options du menu de sélection des actions pour la mise à jours des enregistrements sous la forme 
     * array(
     *    array('label' => '', 'value' => '', 'attrs' => array()),
     * )
     * 
     * @access protected
	 * @return array
	 */	
    protected function _set_select_actions_for_update_records()
    {
        $actions = array();
      
        // (Dés)Activation des enregistrements
        if (!empty($this -> _writer_rights['qcm_questions_act'])) {
            $actions[] = array('label' => ucfirst($this -> _lang['activate_docs_selected']),   'value' => 'a');
            $actions[] = array('label' => ucfirst($this -> _lang['inactivate_docs_selected']), 'value' => 'i');            
        }

        // Suppression des enregistrements
        if (!empty($this -> _writer_rights['qcm_questions_del'])) {
            $actions[] = array('label' => ucfirst($this -> _lang['delete_docs_selected']), 'value' => 'd', 'attrs' => array());
        }

        // Ordre des enregistrements
        if (!empty($this -> _writer_rights['qcm_questions_order'])) {
            $actions[] = array('label' => ucfirst('ordonner les documents sélectionnés'), 'value' => 'o', 'attrs' => array());
        }

        return $actions;
    }

	// --------------------------------------------------------------------

	/**
	 * Met à jour les données des enregistrements selon l'action sélectionnée
     * 
     * @access protected
     * @param array Identifiants des enregistrements à mettre à jour
     * @param string Identifiant de l'action à appliquer pour la mise à jour
	 * @return boolean
	 */
    protected function _update_records_by_action($records_ids, $action)
    {        
        // (Dés)Activation des enregistrements
        if (in_array($action, array('a', 'i'))) {
            return $this -> _activate_records_or_not($records_ids, $action);
        }
        // Suppression des enregistrements
        elseif ($action == 'd') { 
            return $this -> _delete_records($records_ids);
        }
        //ordonner les enregistrements
        elseif ($action == 'o') {
            return $this -> _order_records($records_ids);    
        }        
        
        return FALSE;
    }

	// --------------------------------------------------------------------

	/**
	 * Active ou désactive les enregistrements sélectionnés
     * 
     * @access public
     * @param array Tableau contenant les identifiants des enregistrements
     * @param string action à appliquer (a = activation et i = désactivation)
	 * @return boolean
	 */
    protected function _activate_records_or_not($records_ids, $action)
    {
        if (!empty($this -> _writer_rights['qcm_questions_act'])) {
            return $this -> CI -> qcm_questions_ids_model -> update_status_by_id($records_ids, $action);
        }
        
        return FALSE;
    }
    
	// --------------------------------------------------------------------

	/**
	 * supprime les enregistrements sélectionnés
     * 
     * @access public
     * @param array Tableau contenant les identifiants des enregistrements
	 * @return boolean
	 */
    protected function _delete_records($records_ids)
    {      
        if (!empty($this -> _writer_rights['qcm_questions_del'])) {
            return $this -> CI -> qcm_questions_ids_model -> update_status_by_id($records_ids, 'd');
        }
        
        return FALSE;
    }
    
	// --------------------------------------------------------------------

	/**
	 * ordonne les enregistrements sélectionnés
     * 
     * @access public
     * @param array Tableau contenant les identifiants des enregistrements
	 * @return boolean
	 */
    protected function _order_records($records_ids)
    {      
        if (!empty($this -> _writer_rights['qcm_questions_order'])) {
            $records_order = Var_helper :: import('orders', 'post', array(), array('trim'), array(array('Var_helper', 'is_digit_no_zero')));
            
            return $this -> CI -> qcm_questions_ids_model -> update_order_by_id($records_ids, $records_order);
        }
        
        return FALSE;
    }
   
	// --------------------------------------------------------------------

    /*
     * Affiche ou renvoie le contenu de la vue
     *
	 * @access protected
     * @param array Données des enregistrements
     * @param boolean Renvoie le contenu (TRUE) ou affiche (FALSE) de la vue
     * @return string|void
     */
    protected function _build_view($records)
    {
        return parent :: _build_view($records);
    }    

	// --------------------------------------------------------------------

    /**
	 * Définit et retourne le layout de la vue
     * 
	 * @access protected
     * @return string nom du fichier qui définit le layout
	 */	
    protected function _get_layout_for_manage_records_view()
    {
        return parent :: _get_layout_for_manage_records_view();   
    }

	// --------------------------------------------------------------------

	/**
	 * construit le formulaire de sélection des données
     * 
     * @access protected
	 * @return string Formulaire html
	 */	
    protected function _build_form_data_filtering()
    {
        $data = array(
            'lang' => $this -> _lang,
            'config' => $this -> _config,
            'form_uri' => Url_helper :: build_uri().'/search',
            'qcms' => $this -> _get_qcms_allowed(),
            'qcm_id' => $this -> _qcm_id,
        );
        
        return $this -> CI -> render('../addons/qcm/views/fragments/form_qcm_filtering', $data, TRUE);

    }

	// --------------------------------------------------------------------

	/**
	 * retourne la liste des qcm pris en charge pour la gestion des questions
	 *
	 * @access	protected
	 * @return	array sous la forme array(id => name)
	 */
    protected function _get_qcms_allowed()
    {        
        $this -> CI -> load_addon_helper('qcm', 'qcm_questions_helper');
        
        return $this -> CI -> qcm_questions_helper -> get_qcm_allowed_for_manage_questions($this -> CI -> qcm_ids_model, $this -> _writer_rights);           
    }
    
	// --------------------------------------------------------------------

	/**
	 * construit le tableau de données
     * 
	 * @return string Tableau HTML contenant les enregistrements
	 * @access public
	 */	
    protected function _build_data_table($records)
    {		
        return parent :: _build_data_table($records);        
    }

	// --------------------------------------------------------------------
  
	/**
	 * ajoute des données supplémentaires à l'enregistrement
     * 
	 * @access protected
     * @param array Tableau de données initiales de l'enregistrement
	 * @return array Tableau contenant les nouvelles données de l'enregistrement
	 */    
    protected function _add_more_data_for_record($record)
    {
        return $this -> CI -> qcm_questions_ids_model -> get_by_id($record['id']);        
    }
    
	// --------------------------------------------------------------------
  
	/**
	 * Définit et renvoie les entêtes de la table de données
     * 
	 * @access protected
	 * @return array Tableau contenant les entêtes du tableau de données
	 */    
    protected function _set_data_table_headers()
    {
		$headers = array(
            parent :: _set_data_table_header_for_id(),
            $this -> _set_data_table_header_for_display_order(),
			parent :: _set_data_table_header_for_description($this -> _lang['title']),
            parent :: _set_data_table_header_for_status(),
            ADMR_IS_ADMIN ? parent :: _set_data_table_header_for_state() : array(),
            parent :: _set_data_table_header_for_commands(),
		);

        return $headers;
    }
    
	// --------------------------------------------------------------------
  
	/**
	 * Définit et renvoie l'entêtes de la colonne Ordre d'affichage de la table de données
     * 
	 * @access protected
	 * @return array Tableau contenant l'entêtes de la colonne Ordre d'affichage
	 */    
    protected function _set_data_table_header_for_display_order()
    {
        $title = ucfirst('ordre d\'affichage');
        
        if (in_array('order_asc', $this -> _sort_options)) {
            $title = $this -> _anchor_sort_records($title, 'order');  
        }        
                
        return array('contents' => $title, 'attrs' => array('id' => 'rorder'));
    }

	// --------------------------------------------------------------------
  
	/**
	 * Définit et renvoie le contenu des cellules de la table de données
     * 
	 * @access protected
	 * @param array Données de l'enregistrement
	 * @return array Tableau contenant le contenu des cellules de la table de données
	 */    
    protected function _set_data_table_cells($record)
    {
    	$cells = array(
            parent :: _set_data_table_cell_for_id($record),
            $this -> _set_data_table_cell_for_display_order($record),
            parent :: _set_data_table_cell_for_description($record),
            parent :: _set_data_table_cell_for_status($record),
            ADMR_IS_ADMIN ? parent :: _set_data_table_cell_for_state($record) : array(),
            parent :: _set_data_table_cell_for_commands($record),
    	);
        
        return $cells;
    }

	// --------------------------------------------------------------------
  
	/**
	 * Définit et renvoie le contenu et les attributs de la cellule "Ordre d'affichage" de la table de données
     * 
	 * @access protected
	 * @param array Données de l'enregistrement
	 * @return array Tableau contenant le contenu et les attributs de la cellule "Id" de la table de données sous la forme
     *               array('contents' => '', 'attrs' => array())
	 */    
    protected function _set_data_table_cell_for_display_order($record)
    {
        return array('contents' => $this -> _add_contents_for_td_display_order($record), 'attrs' => array('align' => 'left'));
    }

	// --------------------------------------------------------------------

	/**
	 * Définit et renvoie le contenu de la cellule "Ordre d'affichage" du tableau de données
     * 
	 * @access private
	 * @param array Données de l'enregistrement
	 * @return string Contenu html de la cellule
	 */
	protected function _add_contents_for_td_display_order($record)
	{
		$id = $record['id'];
        $order = $record['display_order'];
        $view = '';
        
        if (!empty($this -> _writer_rights['qcm_questions_order'])) {
            $view .= Html_helper :: addLabel(
                $content = ucfirst($this -> _lang['question_n°']),
                $attr = array('for' => 'order'.$id)
    		);	
            $view .= '&nbsp;';            
            $view .= Html_helper :: addInput(
                $type = 'text',
                $name = 'orders['.$id.']',
                $value = $order,
                $attr = array(
                    'id' => 'order'.$id,
                    'size' => 1,
                    'data-validation' => 'display_order',
                    'data-validation-error-msg-order-required' => $this -> _lang['form_errors_msg']['non_zero_number_is_required'] ,
                    'data-validation-error-msg-order-no-digit' => $this -> _lang['form_errors_msg']['value_is_not_integer']                 
                )
    		);
            
/*             $view .= Html_helper :: openSelect(
                $name = 'orders['.$id.']',
                $attr = array('id' => 'order'.$id, 'size' => 1)
    		 );

            for($i = 1; $i < ($this -> _count_records()+1); $i++) {
                $view .= Html_helper :: addOption(
                    $legend = $i,
                    $value = $i,
                    $attr = array('selected' => ($i == $order)? 'selected' : '')
        		);                   
            }

            $view .= Html_helper :: closeSelect();*/

        } else {
            $view .= ucfirst($this -> _lang['question_n°']).'&nbsp;'.$order;
        }
        
		return $view;
	}

	// --------------------------------------------------------------------

	/**
	 * Renvoie le nombre d'enregistrements
     * 
	 * @access private
	 * @return integer Nombre d'enregistrements
	 */
	protected function _count_records()
	{        
		static $counter = 0;
        
        if (empty($counter)) {
            $counter = count($this -> _get_records());    
        }
        
        return $counter;
	}

	// --------------------------------------------------------------------

	/**
	 * Ajoute le contenu de la cellule "Id" du tableau de données
     * 
	 * @access private
	 * @param array Données de l'enregistrement
	 * @return string Contenu html de la cellule
	 */
	protected function _add_contents_for_td_id($record)
	{        
		return parent :: _add_contents_for_td_id($record);
	}

	// --------------------------------------------------------------------

	/**
	 * Ajoute le contenu à la cellule "Description" du tableau de données
     * 
	 * @access protected
	 * @param array Données de l'enregistrement
	 * @return string Contenu html de la cellule
	 */
	protected function _add_contents_for_td_description($record)
	{
        if (!empty($this -> _writer_rights['qcm_questions_edit'])) {
            return parent :: _add_contents_for_td_description($record);
        } else {
            return $this -> _get_text_for_td_description($record);
        }
	}

	// --------------------------------------------------------------------

	/**
	 * Renvoie le texte de la cellule intitulée "Description"
     * 
	 * @access protected
	 * @param array Données de l'enregistrement
	 * @return string Contenu html de la cellule
	 */
    protected function _get_text_for_td_description($record)
    {
        return $this -> CI -> qcm_questions_ids_model -> set_doc_heading($record);      
    }

	// --------------------------------------------------------------------

	/**
	 * Renvoie l'url du lien du document dans la cellule intitulée "Description"
     * 
	 * @access protected
	 * @param array Données de l'enregistrement
	 * @return string Url du lien
	 */
    protected function _build_href_for_td_description($record)
    {
		$base_href = (ADMR_IS_ADMIN) ? CHEMIN.'admin/'.ADMR_BASE_HREF_PLUGIN : ADMR_BASE_HREF_PLUGIN;

        return $base_href.'&ctrl=addons/qcm/add_qcm_questions&id='.$record['id'].'&qcm_id='.$this -> _qcm_id;       
    }

	// --------------------------------------------------------------------

	/**
	 * Ajoute le contenu de la cellule "Etat" du tableau de données
     * 
	 * @access protected
	 * @param array Données de l'enregistrement
	 * @return string Contenu html de la cellule
	 */
	protected function _add_contents_for_td_state($record)
	{
		return parent :: _add_contents_for_td_state($record);
	}

	// --------------------------------------------------------------------

	/**
	 * Ajoute le contenu de la cellule "Status" du tableau de données
     * 
	 * @access protected
	 * @param array Données de l'enregistrement
	 * @return string Contenu html de la cellule
	 */
	protected function _add_contents_for_td_status($record)
	{
		return parent :: _add_contents_for_td_status($record);
	}

	// --------------------------------------------------------------------

	/**
	 * Ajoute le contenu de la cellule "Commandes" du tableau de données
     * 
	 * @access protected
	 * @param array Données de l'enregistrement
	 * @return string Contenu html de la cellule
	 */
	protected function _add_contents_for_td_commands($record)
	{
        $id = $record['id'];
       
        $view = '';
        
        // Prévisualisation
        $view .= Html_helper :: addA(
			$href = ADMR_SITE_URL.'plugins/qcm/qcm.php?lng='.ADMR_LNG.'&amp;pg='.$this -> _qcm_id.'&amp;question='.$id,
			$contents = Html_helper :: addImg(
				$path = ADMR_IMG_LOOK,
				$alt = ucfirst($this -> _lang['view']),
				$attr = array(
					'title' => $alt,
					'border' => '0'
				)
			)
            .'&nbsp;&nbsp;',
			$attr = array('target' => '_blank')
		);
        
        return $view;
	}

	// --------------------------------------------------------------------

    /**
	 * Vérifie la validité d'accès au qcm par le rédacteur
     * 
	 * @access public
     * @return void
	 */
    protected function _is_qcm_allowed($qcm_id)
    {
        if (!empty($qcm_id) && ! array_key_exists($qcm_id, $this -> _get_qcms_allowed())) {
            return FALSE;
        }

        return TRUE;    
    }

	// --------------------------------------------------------------------

    /**
	 * Vérifie la validité d'accès au document par le rédacteur
     * 
	 * @access protected
     * @return boolean
	 */
    protected function _is_doc_allowed()
    {   
        if (!empty($this -> _writer_rights[$this -> _doc_infos['name'].'_manage'])) // Autorisation d'accès à la section du document
        { 
            return TRUE;
        }
        
        return FALSE;    
    }

	// --------------------------------------------------------------------

} //End of Class