<?php
/**
 * Plugin Qcm (addon for plugin Adm_redacteurs)
 * Version  : 1.5 (2021/01/03)
 * Compatibility : Guppy v5.x et v6.00.00 et Adm_redacteurs v6.14+
 * Author   : jérôme CROUX (jchouix)
 * Web site : http://lebrikabrak.info/
 * E-mail   : lebrikabrak@free.fr
 * Licence  : GNU Lesser General Public License
 */

defined('ADMR_DIRNAME') OR exit('No direct script access allowed');

class Qcm_params_model extends Model
{    
    /*
    |--------------------------------------------------------------------------
    | Properties
    |--------------------------------------------------------------------------
    */
    private $_data_DB = array(); // Données de la base de données
    private $_file_dir_path = QCM_PARAMS_PATH; // Chemin du répertoire contenant les fichiers des données des documents
    private $_file_prefix = QCM_PARAMS_FILE_PREFIX; // Préfixe du nom du fichier contenant les données du document
    private $_file_ext = INCEXT;

    private $_params = array(
        'id' => 0, // Id du qcm
        'title1' => '', // Titre du document (langue 1)
        'title2' => '', // Titre du document (langue 2)
        'author_id' => 0, // Id de l'auteur du document (0 = admin)

        'icon'      => '',  // Icône
        'sidebars'  => '',  // Mode d'affichage des boîtes latérales
        'group' => '', // Groupe privé de guppy
        
        'createdate' => '', // Dates de publication sous la forme date0('YmdHi') - date1('YmdHi')
        'create_datetime' => '', // Date de création (timestamp)
        'modif_datetime' => '',  // Date de modification (timestamp)      

        'description1' => '', // description (langue 1)
        'description2' => '', // description (langue 2)
 //       'display_questions_in_same_page' => 0, // Affichage de toutes les questions sur la même page
        'display_questions_randomly' => 0,   // Affichage aléatoire des questions du qcm
        'answers_choice' => 0, // Choix des réponses (0 : choix associé à la question, 1 : choix unique, 2 : choix multiple)

        'contents_before1' => '', // contenu avant le fichier html (langue 1)
        'contents_before2' => '', // contenu avant le fichier html (langue 2)
        'contents_after1' => '', // contenu après le fichier html (langue 1)
        'contents_after2' => '', // contenu après le fichier html (langue 2)

        'previous_page_label1' => '', // Intitulé de la page précédente (langue 1)
        'previous_page_uri1' => '', // Lien qui mène vers la page précédente (langue 1)
        'next_page_label1' => '', // Intitulé de la page suivante (langue 1)
        'next_page_uri1' => '', // Lien qui mène vers la page suivante (langue 1)
        'previous_page_label2' => '', // Intitulé de la page précédente (langue 2)
        'previous_page_uri2' => '', // Lien qui mène vers la page précédente (langue 2)
        'next_page_label2' => '', // Intitulé de la page suivante (langue 2)
        'next_page_uri2' => '', // Lien qui mène vers la page suivante (langue 2)

        'display_author' => '', // Affiche le nom de l'auteur
        'display_create_date' => '', // Affiche la date de création
        'display_modif_date' => '', // Affiche la date de modification
        'display_nb_views' => '', // Affiche le nombre de vues
        
        'pubdate0'   => '', // Date début de publication programmée
        'pubhour0'   => '', // Heure de début de publication programmée
        'pubminute0' => '', // Minute de début de publication programmée
        'pubdate1'   => '', // Date de fin de publication programmée
        'pubhour1'   => '', // Heure de fin de publication programmée
        'pubminute1' => '', // Minute de fin de publication programmée
    );

    /*
    |--------------------------------------------------------------------------
    | Constructor
    |--------------------------------------------------------------------------
    */
    public function __construct()
	{

	}

	// --------------------------------------------------------------------

	/**
	 * Renvoie le nom des fichiers enregistrés dans la base de donnée
     * 
     * @access public 
	 * @return boolean
	 */
    public function get_all_files()
	{
        $files = array();
        
        if (!empty($this -> _file_dir_path)) {
            $files = array_slice(scandir($this -> _file_dir_path), 2);
            unset($files[array_search('index.php', $files)]); // Suppression du fichier index.php
        }
        
        return $files;
	}

	// --------------------------------------------------------------------

	/**
	 * Renvoie les identifiants des fichiers enregistrés dans la base de donnée
     * 
     * @access public 
	 * @return boolean
	 */
    public function get_files_ids()
	{
        $files_ids = array();
        $files = $this -> get_all_files();

        foreach($files as $key => $file) {
            $files_ids[] = str_replace(array($this -> _file_prefix, $this -> _file_ext), '', $file);
        }
        
        return $files_ids;
	}

	// --------------------------------------------------------------------

	/**
	 * Vérifie si le document existe ou non
     * 
     * @access public 
	 * @param integer Identifiant du document
	 * @return boolean
	 */
    public function file_exists($doc_id = 0)
	{
        if (!empty($doc_id) && ctype_digit((string) $doc_id) && is_file($this -> _get_file_path($doc_id))) {            
            return TRUE;    
        }
        
        return FALSE;
	}

	// --------------------------------------------------------------------

	/**
	 * Lit et renvoie dans un tableau les données enregistrées dans le document identifié par la valeur de son id
     * 
     * @access public 
	 * @param integer Identifiant du document
	 * @return array Tableau contenant les valeurs du document
	 */
    public function read($doc_id = 0)
    {
        $data = array_merge($this -> _params,
            array(
                'pubdate0'   => Date_helper :: get_current_date(),   // Date début de publication programmée
                'pubhour0'   => Date_helper :: get_current_hour(),    // Heure de début de publication programmée
                'pubminute0' => Date_helper :: get_current_minutes(), // Minute de début de publication programmée
                'sidebars'   => 'S',      // Mode d'affichage des boîtes latérales
            )
        );
        
        if ($this -> file_exists($doc_id)) {
            $data = array_merge($data, (array) unserialize(file_get_contents($this -> _get_file_path($doc_id))));    
        }
       
        return $data; 
    }
    
	// --------------------------------------------------------------------
 
	/**
	 * Ecrit les données du document dans un fichier
     * 
     * @access public 
     * @param array Données du rédacteur ou du groupe rédacteur
	 * @return array
	 */    
    public function write($data)
    {
        settype($data, 'array');

        if (empty($data['id']) || ! ctype_digit((string) $data['id'])) {
            return FALSE;
        }
      
        $file_path = $this -> _get_file_path($data['id']);
        $data = $this -> _clean($data);
        $data['createdate'] = Date_helper :: convert_pubdates_to_createdate(array($data['pubdate0'], $data['pubdate1']), array($data['pubhour0'], $data['pubhour1']), array($data['pubminute0'], $data['pubminute1']));
		$data['create_datetime'] = Date_helper :: get_time_from_pubdate($data['pubdate0'], $data['pubhour0'], $data['pubminute0']);
        $data['modif_datetime']  = time();
                
		return file_put_contents($file_path, serialize($data), LOCK_EX);
    }

	// --------------------------------------------------------------------
 
	/**
	 * Supprime les documents identifiés par leur id
     * 
     * @access public 
     * @param array|integer Identifiants des documents à supprimer
	 * @return boolean
	 */    
    public function delete_by_id($doc_ids)
    {
        settype($doc_ids, 'array');

        if (empty($this -> _file_dir_path) || empty($doc_ids)) {
            return FALSE;
        }
                
        foreach($doc_ids as $doc_id) {
            if ($this -> file_exists($doc_id)) {
                @unlink($this -> _get_file_path($doc_id));    
            }
        }
       
        return TRUE; 
    }
   
	// --------------------------------------------------------------------
 
	/**
	 * Retourne le chemin du fichier associé à l'id passé en paramètre
     * 
     * @access private 
     * @param integer Id du document
	 * @return string Chemin du fichier associé à l'id passé en paramètre
	 */    
    private function _get_file_path($doc_id)
    {
        return $this -> _file_dir_path.'/'.$this -> _file_prefix.$doc_id.$this -> _file_ext;    
    }

	// --------------------------------------------------------------------
 
	/**
	 * Nettoie les données du rédacteur
     * 
     * @access private 
	 * @param array Données du rédacteur à nettoyer
	 * @return array
	 */        
    private function _clean($data)
    {
        $data_by_default = $this -> _params;
        $data = $this -> _parse_params_contents($data);
                
        return array_merge($data_by_default, array_intersect_key($data, $data_by_default));
    }

	// --------------------------------------------------------------------
 
	/**
	 * Nettoie les données de type "contenu"
     * 
     * @access private 
	 * @param array Données à nettoyer
	 * @return array
	 */
    private function _parse_params_contents($params)
    {
        $in = array(
    		'\\',
    		'="'.ADMR_SITE_URL
    	);

    	$out = array(
    		'&#92;',
    		'="'
    	);       
        
        foreach(array('contents_before1', 'contents_before2', 'contents_after1', 'contents_after2') as $key) {
            if (!empty($params[$key])) {
                $params[$key] = str_replace($in, $out, $params[$key]);
            }            
        }        

        return $params;
    }

	// --------------------------------------------------------------------
  
	/**
	 * Définit et renvoie les règles de validation des paramètres
     * 
     * @access public 
	 * @param array Tableau contenant les paramètres à valider
	 * @param array Tableau contenant les messages d'erreur
	 * @param array Tableau contenant les options de configuration
	 * @return array Tableau contenant les règles de validation et les messages d'erreur associés
	 */
    public function set_params_rules($params, $lang, $config)
    {
        return array_merge(
            Params_rules_helper :: set_params_author_rules($lang),            // Author
            Params_rules_helper :: set_params_email_rules($lang),             // Email        
            Params_rules_helper :: set_params_status_rules($lang, (ADMR_IS_ADMIN) ? array('a', 'i', 'd') : array('a', 'i')), // Status
            Params_rules_helper :: set_params_pubdates_rules($params, $lang), // Dates de publication
            Params_rules_helper :: set_params_icon_rules($lang, $config),     // Icon
            Params_rules_helper :: set_params_group_rules($lang),             // Group privé
            Params_rules_helper :: set_params_title_rules($lang, $config),    // Titre du document
            Params_rules_helper :: set_params_sidebars_mode_display_rules($lang, $config),    // Mode d'affichage des boites latérales

            array(
                'display_questions_randomly' => array( // Affichage aléatoire des questions
                    array(
                        'rules' => array(array('Var_helper', 'is_binary')),
                        'msg' => htmlspecialchars($lang['form_errors_msg']['field_not_valid'], ENT_QUOTES, 'UTF-8')
                    ),
                ),
/*                'display_questions_in_same_page' => array( // Affichage de toutes les questions dans la même page
                    array(
                        'rules' => array(array('Var_helper', 'is_binary')),
                        'msg' => htmlspecialchars($lang['form_errors_msg']['field_not_valid'], ENT_QUOTES, 'UTF-8')
                    ),
                ),*/
                'answers_choice' => array( // Choix unique ou multiple des réponses aux questions
                    array(
                        'rules' => array(array('Var_helper', 'is_digit')),
                        'msg' => htmlspecialchars($lang['form_errors_msg']['field_not_valid'], ENT_QUOTES, 'UTF-8')
                    ),
                ),
            )
        );
    }
     

	// --------------------------------------------------------------------
  
	/**
	 * Définit et renvoie les choix des réponses possibles
     * 
     * @access public 
	 * @param array Tableau contenant les intitulés
	 * @param array Tableau contenant les options de configuration
	 * @return array Tableau contenant les choix des réponses possibles et les intitulés associés
	 */
    public function set_answers_choices($lang, $config = array())
    {
        return array(
            0 => $lang['answers_choice_by_question'], // Choix selon les paramètres de la question
            1 => $lang['answers_choice_unique'],      // Choix unique pour toutes questions
            2 => $lang['answers_choice_multiple']     // Choix multiple pour toutes les questions    
        );
    }
} // End of Class